pub struct LogArgs {
pub verbose: u8,
pub log_file: Option<PathBuf>,
pub log_no_color: bool,
}Expand description
Logging configuration arguments.
Fields
verbose: u8Increase logging verbosity (-v = error, -vv = warn, -vvv = info, -vvvv = debug, -vvvvv = trace)
log_file: Option<PathBuf>Log file path. If specified, logs are written to this file instead of stderr.
log_no_color: boolDisable colorful console logging. Only applies when logging to stderr (no –log.file).
Implementations
Sourceimpl LogArgs
impl LogArgs
Sourcepub fn init(&self)
pub fn init(&self)
Initialize the tracing subscriber based on the logging configuration.
The log level is determined in the following order of precedence:
RUST_LOGenvironment variable (if set)-vflags (increases from ERROR to WARN/INFO/DEBUG/TRACE)- Default is no logging (OFF)
Log target is only shown for DEBUG level and above.
If --log.file is specified, logs are written to the file instead of stderr.