OverriddenTx

Struct OverriddenTx 

pub struct OverriddenTx<T: Copy> { /* private fields */ }
A wrapper that applies overrides when converting to TxEnv.

This wrapper implements all the required traits by delegating to the inner transaction, but intercepts IntoTxEnv to apply overrides.

Implementations

Source

impl<T: Copy> OverriddenTx<T>

pub fn inner(&self) -> &T

Get a reference to the inner transaction.