Shared building blocks: RPC provider/session, state, env, error, output formatting, tracing, transaction utilities.
Structs
- Account
State - Account state information
- Block
EnvArgs - Block environment configuration arguments
- Build
Provider Output - Return value of the
RpcArgs::build_*_providermethods. - Chain
Args - Chain configuration arguments (spec and chain ID)
- Decoded
RawTx - Result of decoding a raw EIP-2718 transaction.
- EnvArgs
- Environment configuration arguments (chain config, block env, SALT bucket capacity)
- Evme
Outcome - Common execution outcome for all evme commands
- Evme
State - State database that can be backed by either
EmptyDBorAlloyDB(forked from RPC) - Execution
Summary - Serializable execution summary for JSON output
- ExtEnv
Args - External environment configuration arguments (SALT bucket capacity)
- External
EnvSnapshot - Snapshot of mega-evm external environment inputs not derivable from RPC.
- Fixed
Hardfork - Fixed hardfork configuration for replay
- LogArgs
- Logging configuration arguments.
- Output
Args - Output format configuration
- Overridden
Tx - A wrapper that applies overrides when converting to
TxEnv. - PreState
Args - Pre-execution state configuration arguments
- RpcArgs
- Configuration for building an RPC provider.
- RpcCache
Store - Clean-exit cache persistence handle.
- State
Dump Args - State dump configuration arguments
- Trace
Args - Trace configuration arguments
- TxArgs
- Transaction configuration arguments
- TxOverride
Args - Transaction override arguments for the replay command.
- TxOverrides
- Parsed transaction overrides.
Enums
- Evme
Error - Error types for the replay command
- Tracer
Type - Tracer type for execution analysis
Constants
- DEFAULT_
SENDER - Default sender address (Hardhat account #0).
Functions
- load_
hex - Load hex-encoded bytes from an argument or a file. If the file is a dash (-), read from stdin.
Priority: arg > file. Returns
Noneif neither is provided. - op_
receipt_ to_ tx_ receipt - Convert an
OpReceiptEnvelopeto an OP transaction receipt. - parse_
bucket_ capacity - Parse bucket capacity string in format “
bucket_id:capacity” Returns (bucket_id, capacity) tuple - parse_
ether_ value - Parse ether value string into wei (U256). Supports: plain number (wei), or number with suffix (ether, gwei, wei, etc). Examples: “1000000000000000000”, “1ether”, “100gwei”, “1000wei”
- print_
execution_ summary - Print a human-readable execution summary.
- print_
execution_ trace - Print execution trace to console or write to file.
- print_
receipt - Print a receipt as pretty-printed JSON.
Type Aliases
- Evme
External Envs - External environment type for mega-evme using the real AHash-based SALT bucket hasher.
- OpProvider
- OP-stack provider type used throughout mega-evme.
- OpTx
Receipt - OP-stack transaction receipt type alias
- Result
- Result type for the mega-evme command