pub fn print_execution_trace(
trace: Option<&str>,
output_file: Option<&Path>,
) -> Result<(), EvmeError>Expand description
Print execution trace to console or write to file.
If output_file is provided, writes the trace to the file and prints the path.
Otherwise, prints the trace to the console.