pub struct OverriddenTx<T: Copy> { /* private fields */ }Expand description
A wrapper that applies overrides when converting to TxEnv.
This wrapper implements all the required traits by delegating to the inner
transaction, but intercepts IntoTxEnv to apply overrides.
Implementations